@@ -53,4 +53,6 @@ void BarUiStartEventCmd (const BarSettings_t *, const char *,
 bool BarUiPianoCall (BarApp_t * const, const PianoRequestType_t,
 		void *, PianoReturn_t *, CURLcode *);
 void BarUiHistoryPrepend (BarApp_t *app, PianoSong_t *song);
+void BarUiCustomFormat (char *dest, size_t destSize, const char *format,
+		const char *formatChars, const char **formatVals);
 
