@@ -785,7 +785,12 @@ BarUiActCallback(BarUiActManageStation) {
 	}
 
 	/* enable submenus depending on data availability */
-	strcpy (question, "Delete ");
+	if (reqData.info.artistSeeds != NULL ||
+			reqData.info.songSeeds != NULL ||
+			reqData.info.stationSeeds != NULL ||
+			reqData.info.feedback != NULL) {
+		strcpy (question, "Delete ");
+	}
 	if (reqData.info.artistSeeds != NULL) {
 		strcat (question, "[a]rtist");
 		*allowedPos++ = 'a';
@@ -814,15 +819,22 @@ BarUiActCallback(BarUiActManageStation) {
 		strcat (question, "[f]eedback");
 		*allowedPos++ = 'f';
 	}
-	/* station mode is always available */
 	if (allowedPos != allowedActions) {
 		strcat (question, "? ");
 	}
-	strcat (question, "Manage [m]ode? ");
-	*allowedPos++ = 'm';
+	/* station mode is not available for QuickMix. */
+	if (!selStation->isQuickMix) {
+		strcat (question, "Manage [m]ode? ");
+		*allowedPos++ = 'm';
+	}
 
 	*allowedPos = '\0';
 
+	if (allowedPos == allowedActions) {
+		BarUiMsg (&app->settings, MSG_INFO, "No actions available.\n");
+		return;
+	}
+
 	assert (strlen (question) < sizeof (question) / sizeof (*question));
 
 	BarUiMsg (&app->settings, MSG_QUESTION, "%s", question);
